@@ -1,5 +1,5 @@
 #coding = utf-8
-__version__ = '0.4.0'
+__version__ = '0.4.1'
 
 import random
 from termcolor import colored, cprint
@@ -10,7 +10,7 @@ import os
 import json
 import getpass
 import uuid
-from Morpion.datas import variables, loading, setGrid, getPlayers, notDone, isWinner 
+from datas import variables, loading, setGrid, getPlayers, notDone, isWinner 
 
 
 
@@ -35,10 +35,10 @@ vars = variables()
 colors = vars.colors
 cases = vars.scheme
 title = vars.title
-commands = {"Windows": ["cls", "exit"], "Linux":["clear", """
-        osascript -e 'tell application "Terminal" to close first window' && exit
-        """], "Darwin": ["clear", """
-        osascript -e 'tell application "Terminal" to close first window' && exit
+commands = {"Windows": ["cls", "exit", "python -m Morpion"], "Linux":["clear", "exit", """
+        python3 -m Morpion
+        """], "Darwin": ["clear", "", """
+        python3 -m Morpion
         """] }
 
 sys = platform.system()
@@ -49,14 +49,13 @@ global joueurs
 joueurs = []
 
 
-print(__name__)
 
 global Player1
 Player1 = colored("X", colors[2])
 global Player2
 Player2 = colored("O", colors[0])
 
-print(__name__)
+
 
 global coup
 coup = 0
@@ -79,7 +78,7 @@ def getCoup(p, casesDispo) -> int:
     return coup 
     
     
-print(__name__)
+
 
 def setGame(joueurs, gameManager):
 
@@ -142,24 +141,24 @@ def game(joueurs, gameManager):
         turn = 11
     EndScreen(turn, gameManager, p1, p2, p)
 
-print(__name__)
 
 
 def eraseDatas(turn, gameManager, p1, p2, p):
-    print('recopier les caractères ci-dessous pour confirmer :')
     captcha = str(uuid.uuid4())
     captcha = captcha[:5]
-    a = input('')
+    print('recopier les caractères suivants pour confirmer : ' + captcha)
+    
+    a = input('-> ')
     if a == captcha:
         gameManager = {"# Error 509 TroubleShooter" : "debug"}
         with open(f'{pathToSave()}/save.json', 'w', encoding='utf-8') as file:
             json.dump(gameManager, file)
             print('Données éffacées ! Le jeu se ferme...')
             time.sleep(1)
-            os.system(commands[sys][2])
+            os.system("p")
     else: 
         print('Erreur de vérification, réessayez.')
-        EndScreen(turn, gameManager, p1, p2)
+        EndScreen(turn, gameManager, p1, p2, p)
 
 def EndScreen(turn, gameManager, p1, p2, p):
     p1stats = gameManager[str(p1)]
@@ -202,7 +201,7 @@ def EndScreen(turn, gameManager, p1, p2, p):
             return endGameChoice()
     mode = int(endGameChoice())
     if mode == 1:
-        os.system(commands[sys][1])
+        quit()
     elif mode == 2:
         setGame([], gameManager)
 
@@ -240,15 +239,17 @@ def isFirst():
             pass
     except FileNotFoundError:
         tprint('First use, initializing filesystem...')
-        os.mkdir(pathToSave())
-        save = open(pathToSave()+'save.json', "w")
+        try:
+            os.mkdir(pathToSave())
+        except FileExistsError:
+            pass
+        save = open(pathToSave()+'/save.json', "w")
         debugDatas = {"#509 troubleshooting": "debug"}
         json.dump(debugDatas, save)
         save.close()
 
 
 
-print(__name__)
 if __name__ == "__main__":
 
     isFirst()
